---
comments: true
---

# Chinese Chess

A Chinese chess program based on `tkintertools` and written in pure Python.

* 🔖 Version: `1.8`
* 📦 Framework: `tkintertools 2.5.9.5`
* ✏️ Author: <https://github.com/Xiaokang2022>
* 🚀 GitHub: <https://github.com/Xiaokang2022/Chess>

![Watchers](https://img.shields.io/github/watchers/Xiaokang2022/Chess?label=Watchers&logo=github&style=flat "Watchers")
![Forks](https://img.shields.io/github/forks/Xiaokang2022/Chess?label=Forks&logo=github&style=flat "Forks")
![Stars](https://img.shields.io/github/stars/Xiaokang2022/Chess?label=Stars&color=gold&logo=github&style=flat "Stars")
![Issues](https://img.shields.io/github/issues/Xiaokang2022/Chess?label=Issues&logo=github&style=flat "Issues")
![Pull Requests](https://img.shields.io/github/issues-pr/Xiaokang2022/Chess?label=Pull%20Requests&logo=github&style=flat "Pull Requests")
![Discussions](https://img.shields.io/github/discussions/Xiaokang2022/Chess?label=Discussions&logo=github&style=flat "Discussions")

![preview](https://github.com/Xiaokang2022/Chess/blob/master/preview.png?raw=true)
